@@ -5,11 +5,11 @@ use Carp;
 use Digest::MD5 qw/md5_hex/;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has 'columns' => (
     is       => 'ro',
-    isa      => 'ArrayRef[Str]',
+    isa      => 'ArrayRef[Str|HashRef]',
     required => 1,
 );
 
@@ -32,35 +32,60 @@ has 'methods' => (
     required => 0,
 );
 
+has 'base_class' => (
+    is       => 'ro',
+    isa      => 'Str',
+    default  => 'DBIx::Class::Core'
+);
+
+has 'view_class' => (
+    is       => 'ro',
+    isa      => 'Str',
+    lazy     => 1,
+    default  => sub {
+        my ($self) = @_;
+        my $schema_class = ref $self->schema;   # XXX There has to be a better way
+        return $schema_class . '::' . $self->_source_name;
+    }
+);
+
 has '_resultset' => (
     is  => 'rw',
     isa => 'DBIx::Class::ResultSet',
 );
 
-sub BUILD {
-    my $self         = shift;
-    my $schema_class = ref $self->schema;   # XXX There has to be a better way
+has '_source_name' => (
+    is      => 'ro',
+    isa     => 'Str',
+    lazy    => 1,
+    default => sub {
+        my ($self) = @_;
+        my $md5 = md5_hex( $self->sql );
+        return "View$md5";
+    }
+);
 
-    my $md5         = md5_hex( $self->sql );
-    my $table       = "table_$md5";
-    my $source_name = "View$md5";
-    my $view_class  = $schema_class . "::$source_name";
+sub BUILD {
+    my $self = shift;
+
+    my $view_class = $self->view_class;
 
     # XXX Again, I'll figure out something better after this hack
+    my $base_class = $self->base_class;
     eval <<"END_VIEW";
 package $view_class;
-use base 'DBIx::Class::Core';
+use base '$base_class';
 END_VIEW
     croak $@ if $@;
 
     $view_class->table_class('DBIx::Class::ResultSource::View');
-    $view_class->table($table);
+    $view_class->table($self->_source_name);
     $view_class->add_columns( @{ $self->columns } );
     $view_class->result_source_instance->is_virtual(1);
     $view_class->result_source_instance->view_definition( $self->sql );
 
-    $self->schema->register_class( $source_name => $view_class );
-    $self->_resultset( $self->schema->resultset($source_name) );
+    $self->schema->register_class( $self->_source_name => $view_class );
+    $self->_resultset( $self->schema->resultset($self->_source_name) );
     $self->_add_methods($view_class);
 }
 
@@ -94,7 +119,7 @@ Version 0.01
     my $report = DBIx::Class::Report->new(
         schema  => $dbic_schema_object,
         sql     => $complicated_sql,
-        columns => \@accessor_names,
+        columns => \@columns_spec,     # same as __PACKAGE__->add_columns()
         methods => {
             method1 => sub { ... },
             method1 => sub { ... },
@@ -155,6 +180,31 @@ Note that the C<methods> key installs methods in each returned result object.
 This allows us to neatly similate inflation or anthing else we need from a
 standard result object.
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item * columns - An array ref of values which will get passed to
+C<DBIx::Class::ResultSet::add_columns> - may be a flat list of column names, or
+also contain column specification hashes.
+
+=item * sql - The SQL with placeholders
+
+=item * schema - A C<DBIx::Class::Schema> instance
+
+=item * methods - A HashRef of optional subroutines to be added to the ::Result
+namespace for the virtual view.
+
+=item * base_class - The base class for the ::Result namespace for the virtual
+view
+
+=item * view_class - The name of the class that has been auto-generated for
+this view
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Curtis "Ovid" Poe, C<< <ovid at cpan.org> >>
